@@ -10,3 +10,8 @@ DEFAULT_PAGE_NO = 1
 DEFAULT_PAGE_NUM_OF_ROWS = 100
 DEFAULT_STATION_BY_ROUTE_ID = "14194"
 DEFAULT_BUSINESS_MAN_NUMBER = ["1208147521"]
+DEFAULT_ITEM_PER_PAGE = 10
+DEFAULT_MULTI_MOVIE_YN = None
+DEFAULT_REP_NATION_CD = None
+DEFAULT_WIDE_AREA_CD = None
+
